Skip to contents

Generic function for setting tool tip options for a chart

Usage

setToolTipOptions(myIO, suppressY = NULL)

Arguments

myIO

an htmlwidget object created by the myIO() function

suppressY

a boolean

Value

the same myIO object with options set for the tooltip formats

Examples

# Suppress the y value in tooltips
myIO() |> setToolTipOptions(suppressY = TRUE)