Skip to contents

Suppresses axes from printing

Usage

suppressAxis(myIO, xAxis = NULL, yAxis = NULL)

Arguments

myIO

an htmlwidget object created by the myIO() function

xAxis

a logical operator defining whether the x axis should be printed or not

yAxis

a logical operator defining whether the y axis should be printed or not

Value

the same myIO object

Examples

# Suppress both axes
myIO() |> suppressAxis(xAxis = TRUE, yAxis = TRUE)
# Suppress only the x axis myIO() |> suppressAxis(xAxis = TRUE)