R/myIO.R
myIO.Rd
myIO R + d3.js project
myIO(data = NULL, width = "100%", height = "400px", elementId = NULL)
an optional point of entry for the data frame or vector
a string of either pixel width or a percentage width
a string of pixel height
a unique id for the htmlwidget object
the same myIO object
myIO(data = mtcars) |> setMargin(top = 40, bottom = 80, left = 60, right = 10)