Learn R Programming

myIO (version 1.2.0)

myio_validate_spec: Validate a myIO Chart Specification

Description

Validates a proposed chart specification against the generated myIO schema.

Usage

myio_validate_spec(spec, columns = NULL)

Value

A list with valid and errors. Errors use stable machine-readable code values.

Arguments

spec

A list with type, mapping, optional transform, and optional columns.

columns

Optional named column type map. When supplied, overrides spec$columns and enables missing-column and numeric-column checks.

Examples

Run this code
myio_validate_spec(list(
  type = "boxplot",
  mapping = list(column_var = "Species", value_var = "Sepal.Width")
))

Run the code above in your browser using DataLab