powered by
Validates a proposed chart specification against the generated myIO schema.
myio_validate_spec(spec, columns = NULL)
A list with valid and errors. Errors use stable machine-readable code values.
valid
errors
code
A list with type, mapping, optional transform, and optional columns.
type
mapping
transform
columns
Optional named column type map. When supplied, overrides spec$columns and enables missing-column and numeric-column checks.
spec$columns
myio_validate_spec(list( type = "boxplot", mapping = list(column_var = "Species", value_var = "Sepal.Width") ))
Run the code above in your browser using DataLab