Sets margins for the top, bottom, left, and right sides of the chart
Arguments
- myIO
an htmlwidget object created by the myIO() function
- top
a numeric value representing in pixels the top margin
- bottom
a numeric value representing in pixels the bottom margin
- left
a numeric value representing in pixels the left margin
- right
a numeric value representing in pixels the right margin
Examples
# Set custom margins
myIO() |> setMargin(top = 50, bottom = 80, left = 60, right = 20)