Learn R Programming

myIO (version 1.2.0)

setMargin: Set Chart Margins

Description

Sets margins for the top, bottom, left, and right sides of the chart

Usage

setMargin(myIO, top = 20, bottom = 40, left = 50, right = 50)

Value

A modified myIO htmlwidget object with updated margin configuration.

Arguments

myIO

an htmlwidget object created by the myIO() function

top

a numeric value representing in pixels the top margin

bottom

a numeric value representing in pixels the bottom margin

left

a numeric value representing in pixels the left margin

right

a numeric value representing in pixels the right margin

Examples

Run this code
# Set custom margins
myIO() |> setMargin(top = 50, bottom = 80, left = 60, right = 20)

Run the code above in your browser using DataLab