powered by
Sets margins for the top, bottom, left, and right sides of the chart
setMargin(myIO, top = 20, bottom = 40, left = 50, right = 50)
A modified myIO htmlwidget object with updated margin configuration.
myIO
an htmlwidget object created by the myIO() function
a numeric value representing in pixels the top margin
a numeric value representing in pixels the bottom margin
a numeric value representing in pixels the left margin
a numeric value representing in pixels the right margin
# Set custom margins myIO() |> setMargin(top = 50, bottom = 80, left = 60, right = 20)
Run the code above in your browser using DataLab