R/setReferenceLines.R
setReferenceLines.Rd
Sets x and y reference lines
setReferenceLines(myIO, xRef = 0, yRef = 0)
an htmlwidget object created by the myIO() function
a list of the reference line value of x
a list of the reference line value of y
the same myIO object
# Add reference lines at x=5 and y=20 myIO() |> setReferenceLines(xRef = 5, yRef = 20)