Learn R Programming

myIO (version 1.2.0)

setReferenceLines: Set Reference Lines

Description

Sets x and y reference lines

Usage

setReferenceLines(myIO, xRef = 0, yRef = 0)

Value

A modified myIO htmlwidget object with reference lines added.

Arguments

myIO

an htmlwidget object created by the myIO() function

xRef

a list of the reference line value of x

yRef

a list of the reference line value of y

Examples

Run this code
# Add reference lines at x=5 and y=20
myIO() |> setReferenceLines(xRef = 5, yRef = 20)

Run the code above in your browser using DataLab