powered by
Sets x and y reference lines
setReferenceLines(myIO, xRef = 0, yRef = 0)
A modified myIO htmlwidget object with reference lines added.
myIO
an htmlwidget object created by the myIO() function
a list of the reference line value of x
a list of the reference line value of y
# Add reference lines at x=5 and y=20 myIO() |> setReferenceLines(xRef = 5, yRef = 20)
Run the code above in your browser using DataLab