Generic function for setting tool tip options for a chart
Examples
# Suppress the y value in tooltips
myIO() |> setToolTipOptions(suppressY = TRUE)
Generic function for setting tool tip options for a chart
# Suppress the y value in tooltips
myIO() |> setToolTipOptions(suppressY = TRUE)