Learn R Programming

myIO (version 1.2.0)

suppressAxis: Suppress Axis Display

Description

Suppresses axes from printing

Usage

suppressAxis(myIO, xAxis = NULL, yAxis = NULL)

Value

A modified myIO htmlwidget object with axis display suppressed.

Arguments

myIO

an htmlwidget object created by the myIO() function

xAxis

a logical operator defining whether the x axis should be printed or not

yAxis

a logical operator defining whether the y axis should be printed or not

Examples

Run this code
# Suppress both axes
myIO() |> suppressAxis(xAxis = TRUE, yAxis = TRUE)

# Suppress only the x axis
myIO() |> suppressAxis(xAxis = TRUE)

Run the code above in your browser using DataLab