powered by
Suppresses axes from printing
suppressAxis(myIO, xAxis = NULL, yAxis = NULL)
A modified myIO htmlwidget object with axis display suppressed.
myIO
an htmlwidget object created by the myIO() function
a logical operator defining whether the x axis should be printed or not
a logical operator defining whether the y axis should be printed or not
# Suppress both axes myIO() |> suppressAxis(xAxis = TRUE, yAxis = TRUE) # Suppress only the x axis myIO() |> suppressAxis(xAxis = TRUE)
Run the code above in your browser using DataLab